m4-patches
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

FYI: 29-gary-builtin-naming-consistency.patch


From: Gary V. Vaughan
Subject: FYI: 29-gary-builtin-naming-consistency.patch
Date: Fri, 12 Oct 2001 21:35:06 +0100
User-agent: Mutt/1.3.16i

Index: ChangeLog
from  Gary V. Vaughan  <address@hidden>
        * m4/input.c (init_builtin_token):  Renamed from init_macro_token,
        since we call these things builtins in the rest of the code!

Index: m4/input.c
===================================================================
RCS file: /cvsroot/m4/m4/m4/input.c,v
retrieving revision 1.15
diff -u -p -u -r1.15 input.c
--- m4/input.c 2001/10/12 19:57:29 1.15
+++ m4/input.c 2001/10/12 20:28:43
@@ -142,7 +142,7 @@ static      int   file_peek                 (void);
 static int   file_read                 (void);
 static void  file_unget                (int ch);
 static void  file_clean                (void);
-static void  init_macro_token          (m4_token *td);
+static void  init_builtin_token        (m4_token *td);
 static int   macro_peek                (void);
 static int   macro_read                (void);
 static int   match_input               (const unsigned char *s);
@@ -592,15 +592,15 @@ m4_pop_wrapup (void)
   return TRUE;
 }
 
 /* When a MACRO token is seen, next_token () uses init_macro_token
    to retrieve the value of the function pointer.  */
 static void
-init_macro_token (m4_token *td)
+init_builtin_token (m4_token *td)
 {
   if (isp->funcs->read_func != macro_read)
     {
       M4ERROR ((warning_status, 0,
-               _("INTERNAL ERROR: Bad call to init_macro_token ()")));
+               _("INTERNAL ERROR: Bad call to init_builtin_token ()")));
       abort ();
     }
 
@@ -1034,7 +1034,7 @@ m4_next_token (m4_token *td)
 
     if (ch == CHAR_MACRO)              /* MACRO TOKEN */
       {
-       init_macro_token (td);
+       init_builtin_token (td);
        (void) next_char ();
 #ifdef DEBUG_INPUT
        print_token("next_token", M4_TOKEN_MACDEF, td);
@@ -592,15 +592,15 @@ m4_pop_wrapup (void)
 }
 
-/* When a MACRO token is seen, next_token () uses init_macro_token
+/* When a MACRO token is seen, next_token () uses init_builtin_token
    to retrieve the value of the function pointer.  */
 static void

-- 
  ())_. Gary V. Vaughan     gary@(oranda.demon.co.uk|gnu.org)
  ( '/  Research Scientist  http://www.oranda.demon.co.uk       ,_())____
  / )=  GNU Hacker          http://www.gnu.org/software/libtool  \'      `&
`(_~)_  Tech' Author        http://sources.redhat.com/autobook   =`---d__/



reply via email to

[Prev in Thread] Current Thread [Next in Thread]